class SimpleVersion

  attr_reader :major, :minor, :micro

  def initialize(major, minor, micro)
    @major = to_integer(major)
    @minor = to_integer(minor)
    @micro = to_integer(micro)
  end

  def SimpleVersion.parse(version_string)
    if version_string.to_s.strip == ""
      raise "version_string cannot be blank"
    end
    pieces = version_string.split(".", 3)
    if pieces.size != 3
      raise "version must have 3 pieces"
    end
    SimpleVersion.new(pieces[0], pieces[1], pieces[2])
  end

  def next_major
    SimpleVersion.new(major+1, 0, 0)
  end

  def next_minor
    SimpleVersion.new(major, minor+1, 0)
  end

  def next_micro
    SimpleVersion.new(major, minor, micro+1)
  end

  def to_s
    "%s.%s.%s" % [major, minor, micro]
  end

  def <=>(other)
    value = major <=> other.major
    if value == 0
      value = minor <=> other.minor
      if value == 0
        value = micro <=> other.micro
      end
    end
    value
  end

  private
  def to_integer(value)
    if value.to_s.match(/^\d+$/)
      value.to_i
    else
      raise "Value[%s] is not an integer" % value
    end
  end

end
